@@ -1,10 +1,9 @@
-from .abc import ABCAPI, Token
 from .api import API
 from .error import APIError, InvalidTokenError
 from .response import APIResponse
+from .token import Token
 
 __all__ = (
-    "ABCAPI",
     "API",
     "APIError",
     "APIResponse",
