@@ -1,7 +1,7 @@
 class APIError(BaseException):
     def __init__(self, code: int, error: str | None = None) -> None:
         self.code, self.error = code, error
-    
+
     def __str__(self) -> str:
         return f"[{self.code}] {self.error or 'Something went wrong'}"
 
@@ -10,7 +10,7 @@ class APIError(BaseException):
 
 
 class InvalidTokenError(BaseException):
-    ...
+    pass
 
 
 __all__ = ("APIError", "InvalidTokenError")
