@@ -1,9 +1,6 @@
-from fntypes.option import Some
-
-from mubble.bot.cute_types import CallbackQueryCute
-from mubble.bot.dispatch.return_manager import CallbackQueryReturnManager
-
-from .abc import BaseStateView
+from mubble.bot.cute_types.callback_query import CallbackQueryCute
+from mubble.bot.dispatch.return_manager.callback_query import CallbackQueryReturnManager
+from mubble.bot.dispatch.view.base import BaseStateView
 
 
 class CallbackQueryView(BaseStateView[CallbackQueryCute]):
@@ -14,7 +11,7 @@ class CallbackQueryView(BaseStateView[CallbackQueryCute]):
         self.return_manager = CallbackQueryReturnManager()
 
     def get_state_key(self, event: CallbackQueryCute) -> int | None:
-        return event.message.map(lambda variative: variative.v.message_id).unwrap_or_none()
+        return event.message_id.unwrap_or_none()
 
 
 __all__ = ("CallbackQueryView",)
