@@ -1,24 +1,22 @@
-import typing
-
 from mubble.bot.dispatch.context import Context
 from mubble.types.enums import MessageEntityType
 from mubble.types.objects import MessageEntity
 
-from .abc import Message, MessageRule
+from .message import Message, MessageRule
 
-Entity: typing.TypeAlias = str | MessageEntityType
+type Entity = str | MessageEntityType
 
 
 class HasEntities(MessageRule):
-    async def check(self, message: Message, ctx: Context) -> bool:
+    def check(self, message: Message) -> bool:
         return bool(message.entities)
 
 
 class MessageEntities(MessageRule, requires=[HasEntities()]):
-    def __init__(self, entities: Entity | list[Entity]):
+    def __init__(self, entities: Entity | list[Entity], /) -> None:
         self.entities = [entities] if not isinstance(entities, list) else entities
 
-    async def check(self, message: Message, ctx: Context) -> bool:
+    def check(self, message: Message, ctx: Context) -> bool:
         message_entities: list[MessageEntity] = []
         for entity in message.entities.unwrap():
             for entity_type in self.entities:
