@@ -2,15 +2,15 @@ import re
 import typing
 
 from mubble.bot.dispatch.context import Context
+from mubble.node.text import Text
 
-from .abc import Message
-from .text import TextMessageRule
+from .abc import ABCRule
 
-PatternLike: typing.TypeAlias = str | typing.Pattern[str]
+type PatternLike = str | typing.Pattern[str]
 
 
-class Regex(TextMessageRule):
-    def __init__(self, regexp: PatternLike | list[PatternLike]):
+class Regex(ABCRule):
+    def __init__(self, regexp: PatternLike | list[PatternLike]) -> None:
         self.regexp: list[re.Pattern[str]] = []
         match regexp:
             case re.Pattern() as pattern:
@@ -19,13 +19,12 @@ class Regex(TextMessageRule):
                 self.regexp.append(re.compile(regex))
             case _:
                 self.regexp.extend(
-                    re.compile(regexp) if isinstance(regexp, str) else regexp
-                    for regexp in regexp
+                    re.compile(regexp) if isinstance(regexp, str) else regexp for regexp in regexp
                 )
 
-    async def check(self, message: Message, ctx: Context) -> bool:
+    def check(self, text: Text, ctx: Context) -> bool:
         for regexp in self.regexp:
-            response = re.match(regexp, message.text.unwrap())
+            response = re.match(regexp, text)
             if response is not None:
                 if matches := response.groupdict():
                     ctx |= matches
