@@ -3,17 +3,19 @@ import typing
 from mubble.bot.dispatch.context import Context
 from mubble.types.enums import MessageEntityType
 
-from .abc import MessageRule
 from .is_from import IsPrivate
-from .markup import Markup, Message
+from .markup import Markup
+from .message import MessageRule
 from .message_entities import MessageEntities
 
 
 class StartCommand(
-    MessageRule, requires=[
-        IsPrivate() & MessageEntities(MessageEntityType.BOT_COMMAND)
-        & Markup(["/start <param>", "/start"]),
-    ]
+    MessageRule,
+    requires=[
+        IsPrivate(),
+        MessageEntities(MessageEntityType.BOT_COMMAND),
+        Markup(["/start <param>", "/start"]),
+    ],
 ):
     def __init__(
         self,
@@ -26,11 +28,9 @@ class StartCommand(
         self.validator = validator
         self.alias = alias
 
-    async def check(self, _: Message, ctx: Context) -> bool:
+    def check(self, ctx: Context) -> bool:
         param: str | None = ctx.pop("param", None)
-        validated_param = (
-            self.validator(param) if self.validator and param is not None else param
-        )
+        validated_param = self.validator(param) if self.validator and param is not None else param
 
         if self.param_required and validated_param is None:
             return False
