@@ -1,12 +1,12 @@
 from .abc import ABCGlobalContext, CtxVar, GlobalCtxVar
 from .global_context import GlobalContext, ctx_var
-from .mubble_ctx import MubbleCtx
+from .mubble_ctx import MubbleContext
 
 __all__ = (
     "ABCGlobalContext",
     "CtxVar",
     "GlobalContext",
     "GlobalCtxVar",
-    "MubbleCtx",
+    "MubbleContext",
     "ctx_var",
 )
