@@ -1,4 +1,4 @@
-from .base import ABCI18n, ABCTranslator, I18nEnum
+from .abc import ABCI18n, ABCTranslator, I18nEnum
 from .middleware import ABCTranslatorMiddleware
 from .simple import SimpleI18n, SimpleTranslator
 
