@@ -351,6 +351,8 @@ class Currency(str, enum.Enum):
     VND = "VND"
     YER = "YER"
     ZAR = "ZAR"
+    XTR = "XTR"
+    """Telegram stars."""
 
 
 class InlineQueryResultType(str, enum.Enum):
@@ -435,12 +437,13 @@ class BotCommandScopeType(str, enum.Enum):
 
 
 class ChatType(str, enum.Enum):
-    """Type of chat, can be either “private”, “group”, “supergroup” or “channel”"""
+    """Type of chat, can be either `private`, `group`, `supergroup` or `channel`."""
 
     PRIVATE = "private"
     GROUP = "group"
     SUPERGROUP = "supergroup"
     CHANNEL = "channel"
+    SENDER = "sender"
 
 
 class ChatMemberStatus(str, enum.Enum):
@@ -466,17 +469,16 @@ class DiceEmoji(str, enum.Enum):
 
 
 class MessageEntityType(str, enum.Enum):
-    """Type of the entity.
-    Currently, can be “mention” (`@username`), “hashtag”
-    (`#hashtag`), “cashtag” (`$USD`), “bot_command” (`/start@jobs_bot`),
-    “url” (`https://telegram.org`), “email” (`do-not-reply@telegram.org`),
-    “phone_number” (`+1-212-555-0123`), “bold” (**bold text**), “italic”
-    (*italic text*), “underline” (underlined text), “strikethrough” (strikethrough
-    text), “spoiler” (spoiler message), “code” (monowidth string), “pre”
-    (monowidth block), “text_link” (for clickable text URLs), “text_mention”
-    (for users [without usernames](https://telegram.org/blog/edit#new-mentions)),
-    “custom_emoji” (for inline custom emoji stickers), “blockquote” (blockquote)
-    [docs](https://core.telegram.org/bots/api#messageentity)"""
+    """Type of the entity. Currently, can be `mention` (@username), `hashtag`
+    (#hashtag or #hashtag@chatusername), `cashtag` ($USD or $USD@chatusername),
+    `bot_command` (/start@jobs_bot), `url` (https://telegram.org), `email`
+    (do-not-reply@telegram.org), `phone_number` (+1-212-555-0123),
+    `bold` (bold text), `italic` (italic text), `underline` (underlined
+    text), `strikethrough` (strikethrough text), `spoiler` (spoiler message),
+    `blockquote` (block quotation), `expandable_blockquote` (collapsed-by-default
+    block quotation), `code` (monowidth string), `pre` (monowidth block),
+    `text_link` (for clickable text URLs), `text_mention` (for users without
+    usernames), `custom_emoji` (for inline custom emoji stickers)."""
 
     MENTION = "mention"
     HASHTAG = "hashtag"
@@ -496,19 +498,20 @@ class MessageEntityType(str, enum.Enum):
     TEXT_LINK = "text_link"
     TEXT_MENTION = "text_mention"
     CUSTOM_EMOJI = "custom_emoji"
+    EXPANDABLE_BLOCKQUOTE = "expandable_blockquote"
 
 
 class PollType(str, enum.Enum):
-    """Poll type, currently can be “regular” or “quiz”"""
+    """Poll type, currently can be `regular` or `quiz`."""
 
     REGULAR = "regular"
     QUIZ = "quiz"
 
 
 class StickerType(str, enum.Enum):
-    """Type of the sticker, currently one of “regular”, “mask”, “custom_emoji”.
+    """Type of the sticker, currently one of `regular`, `mask`, `custom_emoji`.
     The type of the sticker is independent from its format, which is determined
-    by the fields *is_animated* and *is_video*."""
+    by the fields `is_animated` and `is_video`."""
 
     REGULAR = "regular"
     MASK = "mask"
@@ -526,7 +529,7 @@ class MessageOriginType(str, enum.Enum):
 
 
 class StickerSetStickerType(str, enum.Enum):
-    """Type of stickers in the set, currently one of “regular”, “mask”, “custom_emoji”"""
+    """Type of stickers in the set, currently one of `regular`, `mask`, `custom_emoji`."""
 
     REGULAR = "regular"
     MASK = "mask"
@@ -534,8 +537,8 @@ class StickerSetStickerType(str, enum.Enum):
 
 
 class MaskPositionPoint(str, enum.Enum):
-    """The part of the face relative to which the mask should be placed. One of “forehead”,
-    “eyes”, “mouth”, or “chin”."""
+    """The part of the face relative to which the mask should be placed. One of `forehead`,
+    `eyes`, `mouth`, or `chin`."""
 
     FOREHEAD = "forehead"
     EYES = "eyes"
@@ -545,10 +548,10 @@ class MaskPositionPoint(str, enum.Enum):
 
 class InlineQueryChatType(str, enum.Enum):
     """Type of the chat from which the inline query was sent. Can be
-    either “sender” for a private chat with the inline query sender, “private”,
-    “group”, “supergroup”, or “channel”. The chat type should be always known
+    either `sender` for a private chat with the inline query sender, `private`,
+    `group`, `supergroup`, or `channel`. The chat type should be always known
     for requests sent from official clients and most third-party clients,
-    unless the request was sent from a secret chat"""
+    unless the request was sent from a secret chat."""
 
     SENDER = "sender"
     PRIVATE = "private"
@@ -558,15 +561,16 @@ class InlineQueryChatType(str, enum.Enum):
 
 
 class InlineQueryResultMimeType(str, enum.Enum):
-    """MIME type of the content of the video URL, “text/html” or “video/mp4”"""
+    """MIME type of the content of the video URL, `text/html` or `video/mp4`."""
 
     TEXT_HTML = "text/html"
     VIDEO_MP4 = "video/mp4"
 
 
 class InlineQueryResultThumbnailMimeType(str, enum.Enum):
-    """MIME type of the thumbnail, must be one of “image/jpeg”, “image/gif”,
-    or “video/mp4”. Defaults to “image/jpeg”"""
+    """MIME type of the thumbnail, must be one of `image/jpeg`, `image/gif`,
+    or `video/mp4`. Defaults to `image/jpeg`
+    """
 
     IMAGE_JPEG = "image/jpeg"
     IMAGE_GIF = "image/gif"
@@ -599,8 +603,9 @@ class ReactionTypeType(str, enum.Enum):
 
 
 class InlineQueryResultGifThumbnailMimeType(str, enum.Enum):
-    """MIME type of the thumbnail, must be one of “image/jpeg”, “image/gif”,
-    or “video/mp4”. Defaults to “image/jpeg”"""
+    """MIME type of the thumbnail, must be one of `image/jpeg`, `image/gif`,
+    or `video/mp4`. Defaults to `image/jpeg`.
+    """
 
     IMAGE_JPEG = "image/jpeg"
     IMAGE_GIF = "image/gif"
@@ -608,8 +613,9 @@ class InlineQueryResultGifThumbnailMimeType(str, enum.Enum):
 
 
 class InlineQueryResultMpeg4GifThumbnailMimeType(str, enum.Enum):
-    """MIME type of the thumbnail, must be one of “image/jpeg”, “image/gif”,
-    or “video/mp4”. Defaults to “image/jpeg”"""
+    """MIME type of the thumbnail, must be one of `image/jpeg`, `image/gif`,
+    or `video/mp4`. Defaults to `image/jpeg`.
+    """
 
     IMAGE_JPEG = "image/jpeg"
     IMAGE_GIF = "image/gif"
@@ -617,24 +623,25 @@ class InlineQueryResultMpeg4GifThumbnailMimeType(str, enum.Enum):
 
 
 class InlineQueryResultVideoMimeType(str, enum.Enum):
-    """MIME type of the content of the video URL, “text/html” or “video/mp4”"""
+    """MIME type of the content of the video URL, `text/html` or `video/mp4`."""
 
     TEXT_HTML = "text/html"
     VIDEO_MP4 = "video/mp4"
 
 
 class InlineQueryResultDocumentMimeType(str, enum.Enum):
-    """MIME type of the content of the file, either “application/pdf” or “application/zip”"""
+    """MIME type of the content of the file, either `application/pdf` or `application/zip`."""
 
     APPLICATION_PDF = "application/pdf"
     APPLICATION_ZIP = "application/zip"
 
 
 class EncryptedPassportElementType(str, enum.Enum):
-    """Element type. One of “personal_details”, “passport”, “driver_license”,
-    “identity_card”, “internal_passport”, “address”, “utility_bill”,
-    “bank_statement”, “rental_agreement”, “passport_registration”,
-    “temporary_registration”, “phone_number”, “email”."""
+    """Element type. One of `personal_details`, `passport`, `driver_license`,
+    `identity_card`, `internal_passport`, `address`, `utility_bill`,
+    `bank_statement`, `rental_agreement`, `passport_registration`,
+    `temporary_registration`, `phone_number`, `email`.
+    """
 
     PERSONAL_DETAILS = "personal_details"
     PASSPORT = "passport"
@@ -657,3 +664,37 @@ class StickerFormat(str, enum.Enum):
     STATIC = "static"
     ANIMATED = "animated"
     VIDEO = "video"
+
+
+__all__ = (
+    "BotCommandScopeType",
+    "ChatAction",
+    "ChatBoostSourceType",
+    "ChatMemberStatus",
+    "ChatType",
+    "ContentType",
+    "Currency",
+    "DefaultAccentColor",
+    "DiceEmoji",
+    "EncryptedPassportElementType",
+    "InlineQueryChatType",
+    "InlineQueryResultDocumentMimeType",
+    "InlineQueryResultGifThumbnailMimeType",
+    "InlineQueryResultMimeType",
+    "InlineQueryResultMpeg4GifThumbnailMimeType",
+    "InlineQueryResultThumbnailMimeType",
+    "InlineQueryResultVideoMimeType",
+    "MaskPositionPoint",
+    "MessageEntityType",
+    "MessageOriginType",
+    "PassportElementErrorType",
+    "PollType",
+    "ProgrammingLanguage",
+    "ReactionEmoji",
+    "ReactionTypeType",
+    "StickerFormat",
+    "StickerSetStickerType",
+    "StickerType",
+    "TopicIconColor",
+    "UpdateType",
+)
