@@ -2,17 +2,18 @@ import hashlib
 import hmac
 import typing
 
-from mubble.api.abc import Token
 
-
-def verify_webapp_request(secret_token: str, request_headers: typing.Mapping[str, typing.Any]) -> bool:
+def verify_webapp_request(
+    secret_token: str,
+    request_headers: typing.Mapping[str, typing.Any],
+) -> bool:
     """Verifies update request is from telegram."""
 
     return request_headers.get("X-Telegram-Bot-Api-Secret-Token") == secret_token
 
 
 def webapp_validate_request(
-    bot_token: Token,
+    bot_token: str,
     request_query_params: typing.Mapping[str, typing.Any],
 ) -> bool:
     """Verifies authentity of webapp request by counting hash of its parameters."""
